Learn R Programming

scistreer (version 1.2.1)

label_edges: Annotate the direct upstream or downstream mutations on the edges

Description

Annotate the direct upstream or downstream mutations on the edges

Usage

label_edges(G)

Value

igraph Mutation graph

Arguments

G

igraph Mutation graph