Learn R Programming

scistreer (version 1.2.1)

ladderize: From ape; will remove once new ape version is released https://github.com/emmanuelparadis/ape/issues/54

Description

From ape; will remove once new ape version is released https://github.com/emmanuelparadis/ape/issues/54

Usage

ladderize(phy, right = TRUE)

Arguments

phy

phylo The phylogeny

right

logical Whether ladderize to the right

Examples

Run this code
tree_small = ladderize(tree_small)

Run the code above in your browser using DataLab