Learn R Programming

scistreer (version 1.2.1)

to_phylo: Convert the phylogeny from tidygraph to phylo object modified from R package alakazam, converts a tbl_graph to a phylo object

Description

Convert the phylogeny from tidygraph to phylo object modified from R package alakazam, converts a tbl_graph to a phylo object

Usage

to_phylo(graph)

Value

phylo The single-cell phylogeny

Arguments

graph

tbl_graph The single-cell phylogeny

Examples

Run this code
tree_small = to_phylo(annotate_tree(tree_small, P_small))

Run the code above in your browser using DataLab