Learn R Programming

scistreer (version 1.2.1)

transfer_links: Annotate the direct upstream or downstream node on the edges

Description

Annotate the direct upstream or downstream node on the edges

Usage

transfer_links(G)

Value

igraph Mutation graph

Arguments

G

igraph Mutation graph